#ifndef SERIALPORT_H
#define SERIALPORT_H
#include <QMap>
#include <QObject>
#include <QSerialPort>
#include <QTimer>

class SerialPortTool : public QObject {
    Q_OBJECT

public:
    explicit SerialPortTool(QObject* parent = 0);
    ~SerialPortTool();
    void open();
    void close();
public slots:
    void onPlaybackStart();
    void onPlaybackEnd();
    void onRecordStart();
    void onRecordEnd();
    void onPlayPause();
    void onPlayResume();
    void onDiskWillFull();
    void onDiskNotFull();
    void onPowerOn();
    void onPowerOff();
    void onFoward();
    void onBack();
    void onLoopOn();
    void onLoopOff();
    void onMainChannelOn();
    void onMainChannelOff();
    void onSecondaryChannelOn();
    void onSecondaryChannelOff();

private slots:
    void onSerialError(QSerialPort::SerialPortError error);
    void onTimeout();
    void onReayRead();
signals:
    void btnPlaybackClicked();
    void btnPreviousClicked();
    void btnPauseClicked();
    void btnReturnClicked();
    void btnBackClicked();
    void btnNextClicked();
    void btnForwardClicked();
    void btnDoneClicked();

private:
    enum CommandType {
        PlaybackStart,
        PlaybackEnd,
        RecordStart,
        RecordEnd,
        PlayPause,
        PlayResume,
        DiskWillFull,
        DiskNotFull,
        PowerOn,
        PowerOff,
        Forward,
        Back,
        LoopOn,
        LoopOff,
        MainChannelOn,
        MainChannelOff,
        SecondaryChannelOff,
        SecondaryChannelOn
    };

    QSerialPort* serialPort; // 串口
    QMap<CommandType, QByteArray> cmdMap; // 指令列表
    QTimer* timer;
};

#endif // SERIALPORT_H
